@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.1.22
+# Version   : 0.2.0
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -39,7 +39,7 @@ class AFM:
         files without baseline or contact corrections applied, produced
         by input_files function
     z_position_raw: [samples, curve_number]
-        Raw AFM force curve tip position data (nm) imported from nanoscope
+        Raw AFM force curve piezo position data (nm) imported from nanoscope
         files without baseline or contact corrections applied, produced
         by input_files function
     approach: [samples, curve_number]
@@ -49,7 +49,7 @@ class AFM:
         AFM force curve retract data (nN) produced by the baseline function
         and updated by teh contact function
     z_position:[samples, curve_number]
-        AFM force curve tip position data (nm) produced by the baseline
+        AFM force curve tip/piezo position data (nm) produced by the baseline
         function and updated by teh contact function
     adhesion: [curve_number]
         Adhesion (nN) value calculated for each force curve by calc_adhesion
@@ -449,7 +449,7 @@ class AFM:
         fig.add_trace(go.Scatter(y = self.retract_raw[:,curve_number], x = self.z_position_raw[:,curve_number], mode='lines', name = 'Retract curve (raw)'))
         fig.update_layout(
             yaxis_title_text='Force (nN)',
-            xaxis_title_text='Tip separation (nm)',
+            xaxis_title_text='Piezo position (nm)',
         )
         fig.show()
 
@@ -551,8 +551,8 @@ class AFM:
             _approach = self.approach[:,i]
             _retract = self.retract[:,i]
                 
-            tip_approach = _z[:self.samps_line] - self.spr_const * _approach
-            tip_retract = _z[self.samps_line:] - self.spr_const * _retract
+            tip_approach = _z[:self.samps_line] + _approach / self.spr_const
+            tip_retract = _z[self.samps_line:] + _retract / self.spr_const
 
             tip_position = np.concatenate((tip_approach, tip_retract), axis = 0)
 
@@ -571,7 +571,7 @@ class AFM:
         fig.add_trace(go.Scatter(y = self.retract[:,curve_number], x = self.z_position[:,curve_number][self.samps_line:], mode='lines', name = 'Retract curve'))
         fig.update_layout(
             yaxis_title_text='Force (nN)',
-            xaxis_title_text='Tip separation (nm)',
+            xaxis_title_text='Distance, z (nm)',
         )
         fig.show()
 
@@ -628,7 +628,7 @@ class AFM:
         fig.update_layout(
             sliders=sliders,
             yaxis_title_text='Force (nN)',
-            xaxis_title_text='Tip separation (nm)',
+            xaxis_title_text='Distance, z (nm)',
         )
 
         fig.show()
